@@ -9,6 +9,7 @@ from container_service_extension.client.de_cluster_native import DEClusterNative
 from container_service_extension.client.de_cluster_tkg_s import DEClusterTKGS
 from container_service_extension.client.legacy_cluster_native import LegacyClusterNative  # noqa: E501
 from container_service_extension.common.constants.shared_constants import ClusterEntityKind  # noqa: E501
+from container_service_extension.common.constants.shared_constants import CSE_SERVER_RUNTIMES  # noqa: E501
 
 
 class Cluster:
@@ -28,11 +29,11 @@ class Cluster:
 
         :return: instance of version specific client side cluster
         """
-        api_version = client.get_api_version()
-        if float(api_version) < float(vcd_client.ApiVersion.VERSION_35.value):   # noqa: E501
+        api_version = client.get_vcd_api_version()
+        if api_version < vcd_client.VcdApiVersionObj.VERSION_35.value:
             return LegacyClusterNative(client)
-        elif float(api_version) >= float(vcd_client.ApiVersion.VERSION_35.value):  # noqa: E501
-            if k8_runtime == ClusterEntityKind.NATIVE.value or k8_runtime == ClusterEntityKind.TKG_PLUS.value:  # noqa: E501
+        elif api_version >= vcd_client.VcdApiVersionObj.VERSION_35.value:
+            if k8_runtime in CSE_SERVER_RUNTIMES:
                 return DEClusterNative(client)
             elif k8_runtime == ClusterEntityKind.TKG_S.value:
                 return DEClusterTKGS(client)
