@@ -466,8 +466,10 @@ class CseOperation(Enum):
     OVDC_COMPUTE_POLICY_LIST = ('list ovdc compute policies', '/cse/ovdc/%s/compute-policies')  # noqa: E501
     OVDC_COMPUTE_POLICY_UPDATE = ('update ovdc compute policies', '/cse/ovdc/%s/compute-policies')  # noqa: E501
     SYSTEM_INFO = ('get info of system', '/cse/system')
+    SYSTEM_SERVER_CONFIG = ('fetch server runtime configuration', '/cse/system/config')  # noqa: E501
     SYSTEM_UPDATE = ('update system status', '/cse/system')
     TEMPLATE_LIST = ('list all templates', '/cse/templates')
+    TEMPLATE_RELOAD = ('reload native and TKGm templates into server runtime config', '/cse/templates/action/reload', requests.codes.accepted)  # noqa: E501
     TKGM_TEMPLATE_LIST = ('list TKGm templates', '/cse/templates/tkgm')
 
     V35_OVDC_LIST = ('list ovdcs for v35', '/cse/3.0/ovdcs')
@@ -502,6 +504,8 @@ class ClusterMetadataKey(str, Enum):
     KUBERNETES_VERSION = "cse.kubernetes.version"
     CNI = "cse.cni"
     CNI_VERSION = 'cse.cni.version'
+    CPI = "cse.cpi"
+    CSI = "cse.csi"
 
 
 @unique
@@ -801,14 +805,40 @@ class PostCustomizationPhase(Enum):
     NETWORK_CONFIGURATION = 'guestinfo.postcustomization.networkconfiguration.status'  # noqa: E501
     STORE_SSH_KEY = 'guestinfo.postcustomization.store.sshkey.status'
     KUBEADM_INIT = 'guestinfo.postcustomization.kubeinit.status'
+    TKR_GET_VERSIONS = 'guestinfo.postcustomization.tkr.get_versions.status'
     KUBECTL_APPLY_CNI = 'guestinfo.postcustomization.kubectl.cni.install.status'  # noqa: E501
     KUBECTL_APPLY_CPI = 'guestinfo.postcustomization.kubectl.cpi.install.status'  # noqa: E501
     KUBECTL_APPLY_CSI = 'guestinfo.postcustomization.kubectl.csi.install.status'  # noqa: E501
+    KUBECTL_APPLY_DEFAULT_STORAGE_CLASS = 'guestinfo.postcustomization.kubectl.default_storage_class.status'  # noqa: E501
+    KUBECTL_APPLY_KAPP_CONTROLLER = 'guestinfo.postcustomization.kubectl.kapp_controller.install'  # noqa: E501
     KUBEADM_TOKEN_GENERATE = 'guestinfo.postcustomization.kubeadm.token.generate.status'  # noqa: E501
     KUBEADM_NODE_JOIN = 'guestinfo.postcustomization.kubeadm.node.join.status'
     PROXY_SETTING = 'guestinfo.postcustomization.proxy.setting.status'
+    CORE_PACKAGES_ATTEMPTED_INSTALL = 'guestinfo.postcustomization.core_packages.attempted_install'  # noqa: E501
 
 
+# TO_INSTALL versions indicate versions that the control plane node retrieved
+# for worker node(s) to install. INSTALLED_VERSION refers to the version
+# that the worker node(s) were able to install.
+@unique
+class PostCustomizationVersions(Enum):
+    TKR_KAPP_CONTROLLER_VERSION_TO_INSTALL = 'guestinfo.postcustomization.tkr.get_versions.kapp_controller'  # noqa: E501
+    TKR_K8S_VERSION = 'guestinfo.postcustomization.tkr.get_versions.k8s'
+    INSTALLED_VERSION_OF_KAPP_CONTROLLER = 'guestinfo.postcustomization.core_packages.kapp_controller_version'  # noqa: E501
+    INSTALLED_VERSION_OF_METRICS_SERVER = 'guestinfo.postcustomization.core_packages.metrics_server_version'  # noqa: E501
+    INSTALLED_VERSION_OF_ANTREA = 'guestinfo.postcustomization.core_packages.antrea_version'  # noqa: E501
+
+
+@unique
+class CorePkgVersionKeys(Enum):
+    KAPP_CONTROLLER = 'kapp-controller'
+    METRICS_SERVER = 'metrics-server'
+    ANTREA = 'antrea'
+    K8S = 'k8s'
+
+
+PostCustomizationKubeconfig = 'guestinfo.postcustomization.control_plane.kubeconfig'  # noqa: E501
+
 KUBEADM_TOKEN_INFO = 'guestinfo.postcustomization.kubeadm.token.info'
 KUBE_CONFIG = 'guestinfo.kubeconfig'
 POST_CUSTOMIZATION_SCRIPT_EXECUTION_STATUS = 'guestinfo.post_customization_script_execution_status'  # noqa: E501
@@ -825,3 +855,37 @@ MAX_RDE_UPDATE_ATTEMPTS = 10
 # keys of the Behavior task response that gets sent to VCD
 BEHAVIOR_TASK_RESPONSE_RESULT_MESSAGE_KEY = "result"
 BEHAVIOR_TASK_RESPONSE_RESULT_CONTENT_MESSAGE_KEY = "resultContent"
+
+# CPI/CNI/CSI constants
+CPI_NAME = "cloud-provider-for-cloud-director"
+CPI_DEFAULT_VERSION = "1.1.1"
+CSI_NAME = "cloud-director-named-disk-csi-driver"
+CSI_DEFAULT_VERSION = "1.2.0"
+
+UBUNTU_20_04_TEMPLATE_OS = "ubuntu-20.04"
+
+
+@unique
+class TkgmNodeSizing(Enum):
+    """Predefined configuration for TKGm cluster node size.
+
+    1.cpu - number of cpus
+    2.memory - cpu memory size in mb
+    """
+
+    def __init__(self, cpu, memory):
+        self._cpu = cpu
+        self._memory = memory
+
+    @property
+    def cpu(self):
+        return self._cpu
+
+    @property
+    def memory(self):
+        return self._memory
+
+    SMALL = (2, 4096)
+    MEDIUM = (2, 8192)
+    LARGE = (4, 16384)
+    EXTRA_LARGE = (8, 32768)
