@@ -53,7 +53,7 @@ class DefEntityType:
     """Defined Entity type schema for the apiVersion = 35.0."""
 
     name: str
-    description: str
+    description: Optional[str]
     schema: dict
     interfaces: List[str]
     version: str
@@ -84,7 +84,7 @@ class DefEntityType2_0:
     """Defined Entity type schema for the apiVersion = 36.0."""
 
     name: str
-    description: str
+    description: Optional[str]
     schema: dict
     interfaces: List[str]
     version: str
@@ -356,22 +356,22 @@ class EntityType(Enum):
     NATIVE_ENTITY_TYPE_1_0_0 = DefEntityType(
         name='nativeClusterEntityType',
         id=f"{DEF_ENTITY_TYPE_ID_PREFIX}:{Vendor.CSE.value}:{Nss.NATIVE_CLUSTER}:1.0.0",  # noqa: E501
-        schema=load_rde_schema(SchemaFile.SCHEMA_1_0_0),
+        schema=load_rde_schema(SchemaFile.SCHEMA_1_0_0.value),
         interfaces=[K8Interface.VCD_INTERFACE.value.id],
         version='1.0.0',
         vendor=Vendor.CSE.value,
         nss=Nss.NATIVE_CLUSTER.value,
         description=''
     )
-    NATIVE_ENTITY_TYPE_2_0_0 = DefEntityType2_0(
+    NATIVE_ENTITY_TYPE_2_1_0 = DefEntityType2_0(
         name='nativeClusterEntityType',
-        id=f"{DEF_ENTITY_TYPE_ID_PREFIX}:{Vendor.CSE.value}:{Nss.NATIVE_CLUSTER}:2.0.0",  # noqa: E501
-        schema=load_rde_schema(SchemaFile.SCHEMA_2_0_0),
+        id=f"{DEF_ENTITY_TYPE_ID_PREFIX}:{Vendor.CSE.value}:{Nss.NATIVE_CLUSTER}:2.1.0",# noqa: E501
+        schema=load_rde_schema(SchemaFile.SCHEMA_2_1_0.value),
         interfaces=[
             K8Interface.VCD_INTERFACE.value.id,
             K8Interface.CSE_INTERFACE.value.id
         ],
-        version='2.0.0',
+        version='2.1.0',
         vendor=Vendor.CSE.value,
         nss=Nss.NATIVE_CLUSTER.value,
         description='',
@@ -394,7 +394,7 @@ class EntityType(Enum):
     CAPVCD_ENTITY_TYPE_1_0_0 = DefEntityType(
         name='CAPVCD Cluster',
         id=f"{DEF_ENTITY_TYPE_ID_PREFIX}:{Vendor.VMWARE.value}:{Nss.CAPVCD}:1.0.0",  # noqa: E501
-        schema=load_rde_schema(SchemaFile.CAPVCD_1_0_0),
+        schema=load_rde_schema(SchemaFile.CAPVCD_1_0_0.value),
         interfaces=[K8Interface.VCD_INTERFACE.value.id],
         version='1.0.0',
         vendor=Vendor.VMWARE.value,
@@ -415,7 +415,7 @@ MAP_RDE_VERSION_TO_ITS_METADATA = {
     RuntimeRDEVersion.RDE_2_X: {
         RDEMetadataKey.INTERFACES: [K8Interface.VCD_INTERFACE.value,
                                     K8Interface.CSE_INTERFACE.value],
-        RDEMetadataKey.ENTITY_TYPE: EntityType.NATIVE_ENTITY_TYPE_2_0_0.value,
+        RDEMetadataKey.ENTITY_TYPE: EntityType.NATIVE_ENTITY_TYPE_2_1_0.value,
 
         RDEMetadataKey.INTERFACE_TO_BEHAVIORS_MAP: {
             K8Interface.CSE_INTERFACE.value.id:
@@ -425,11 +425,11 @@ MAP_RDE_VERSION_TO_ITS_METADATA = {
                  BehaviorOperation.DELETE_NFS_NODE.value]
         },
         RDEMetadataKey.ENTITY_TYPE_TO_OVERRIDABLE_BEHAVIORS_MAP: {
-            EntityType.NATIVE_ENTITY_TYPE_2_0_0.value.id:
+            EntityType.NATIVE_ENTITY_TYPE_2_1_0.value.id:
                 [BehaviorOperation.GET_KUBE_CONFIG.value]
         },
         RDEMetadataKey.BEHAVIOR_TO_ACL_MAP: {
-            EntityType.NATIVE_ENTITY_TYPE_2_0_0.value.id:
+            EntityType.NATIVE_ENTITY_TYPE_2_1_0.value.id:
                 [BehaviorAcl.CREATE_CLUSTER_ACL.value,
                  BehaviorAcl.UPDATE_CLUSTER_ACL.value,
                  BehaviorAcl.DELETE_CLUSTER_ACL.value,
