@@ -75,8 +75,8 @@ def cse_server():
 
     Setup tasks:
     - If templates do not exist, install CSE using `--upgrade`
-    - Run `cse install` to ensure that CSE is registered and AMQP
-        exchange exists.
+    - Run `cse install` to ensure that CSE is registered and
+        message exchange exists.
     - Run CSE server as a subprocess
 
     Teardown tasks:
@@ -84,21 +84,22 @@ def cse_server():
     """
     env.setup_active_config()
     if env.is_cse_registered():
-        cmd = ['upgrade',
-               '--config', env.ACTIVE_CONFIG_FILEPATH,
-               '--ssh-key', env.SSH_KEY_FILEPATH,
-               '--skip-config-decryption',
-               '--skip-template-creation']
+        cmd = [
+            'upgrade',
+            '--config', env.ACTIVE_CONFIG_FILEPATH,
+            '--skip-config-decryption'
+        ]
     else:
-        cmd = ['install',
-               '--config', env.ACTIVE_CONFIG_FILEPATH,
-               '--ssh-key', env.SSH_KEY_FILEPATH,
-               '--skip-config-decryption',
-               '--skip-template-creation']
+        cmd = [
+            'install',
+            '--config', env.ACTIVE_CONFIG_FILEPATH,
+            '--skip-config-decryption'
+        ]
     result = env.CLI_RUNNER.invoke(cli, cmd, input='y', catch_exceptions=False)
     assert result.exit_code == 0,\
-        testutils.format_command_info('cse', cmd, result.exit_code,
-                                      result.output)
+        testutils.format_command_info(
+            'cse', cmd, result.exit_code, result.output
+        )
 
     # Create missing templates
     for template_config in env.TEMPLATE_DEFINITIONS:
@@ -293,8 +294,10 @@ def test_0030_vcd_cse_cluster_create_rollback(config, vcd_org_admin,
     $ vcd cse cluster create testcluster -n NETWORK -N 1 -c 1000
         --disable-rollback
     """
+    template_name = env.TEMPLATE_DEFINITIONS[0]['name']
+    template_revision = env.TEMPLATE_DEFINITIONS[0]['revision']
     cmd = f"cse cluster create {env.SYS_ADMIN_TEST_CLUSTER_NAME} -n " \
-          f"{env.TEST_NETWORK} -N 1 -c 1000"
+          f"{env.TEST_NETWORK} -N 1 -c 1000 -t {template_name} -r {template_revision}"  # noqa: E501
     result = env.CLI_RUNNER.invoke(vcd, cmd.split(), catch_exceptions=False)
     assert result.exit_code == 0, \
         testutils.format_command_info('vcd', cmd, result.exit_code,
@@ -336,6 +339,8 @@ def test_0050_vcd_cse_system_toggle(config, test_runner_username,
     :param test_runner_username: parameterized persona to run tests with
     different users
     """
+    template_name = env.TEMPLATE_DEFINITIONS[0]['name']
+    template_revision = env.TEMPLATE_DEFINITIONS[0]['revision']
     # Batch cse commands together in a list and then execute them one by one
     cmd_binder = collections.namedtuple('UserCmdBinder',
                                         'cmd exit_code validate_output_func'
@@ -351,7 +356,8 @@ def test_0050_vcd_cse_system_toggle(config, test_runner_username,
         cmd_binder(cmd=f"org use {env.TEST_ORG}", exit_code=0,
                    validate_output_func=None, test_user=test_runner_username),
         cmd_binder(cmd=f"cse cluster create {env.SYS_ADMIN_TEST_CLUSTER_NAME} "
-                       f"-n {env.TEST_NETWORK} -N 1", exit_code=2,
+                       f"-n {env.TEST_NETWORK} -N 1 -t {template_name}"
+                       f" -r {template_revision}", exit_code=2,
                    validate_output_func=None, test_user=test_runner_username),
         cmd_binder(cmd=env.USER_LOGOUT_CMD, exit_code=0,
                    validate_output_func=None, test_user=test_runner_username),
@@ -360,8 +366,9 @@ def test_0050_vcd_cse_system_toggle(config, test_runner_username,
         cmd_binder(cmd="cse system enable", exit_code=0,
                    validate_output_func=None, test_user='sys_admin'),
         cmd_binder(cmd=f"cse cluster create {env.SYS_ADMIN_TEST_CLUSTER_NAME} "
-                       f"-n {env.TEST_NETWORK} -N 1 -c 1000 "
-                       f"--disable-rollback", exit_code=2,
+                       f"-n {env.TEST_NETWORK} -N 1 -c 1000 -t {template_name}"
+                       f" -r {template_revision} --disable-rollback",
+                   exit_code=2,
                    validate_output_func=None, test_user='sys_admin'),
         cmd_binder(cmd=env.USER_LOGOUT_CMD, exit_code=0,
                    validate_output_func=None, test_user='sys_admin')
@@ -388,6 +395,8 @@ def test_0070_vcd_cse_cluster_create(config, test_runner_username):
     :param test_runner_username: parameterized persona to run tests with
     different users
     """
+    template_name = env.TEMPLATE_DEFINITIONS[0]['name']
+    template_revision = env.TEMPLATE_DEFINITIONS[0]['revision']
     cmd_binder = collections.namedtuple('UserCmdBinder',
                                         'cmd exit_code validate_output_func '
                                         'test_user')
@@ -403,7 +412,8 @@ def test_0070_vcd_cse_cluster_create(config, test_runner_username):
                    validate_output_func=None, test_user=test_runner_username),
         cmd_binder(cmd=f"cse cluster create "
                        f"{env.USERNAME_TO_CLUSTER_NAME[test_runner_username]}"
-                       f" -n {env.TEST_NETWORK} -N 0 ", exit_code=0,
+                       f" -n {env.TEST_NETWORK} -N 0 -t {template_name}"
+                       f" -r {template_revision}", exit_code=0,
                    validate_output_func=None, test_user=test_runner_username),
         cmd_binder(cmd=env.USER_LOGOUT_CMD, exit_code=0,
                    validate_output_func=None, test_user=test_runner_username)
@@ -432,7 +442,7 @@ def test_0080_vcd_cse_cluster_list(test_runner_username):
                    exit_code=0,
                    validate_output_func=None, test_user=test_runner_username),
         cmd_binder(cmd="cse cluster list", exit_code=0,
-                   validate_output_func=list_cluster_output_validator,
+                   validate_output_func=list_cluster_output_validator(),
                    test_user=test_runner_username),
         cmd_binder(cmd=env.USER_LOGOUT_CMD, exit_code=0,
                    validate_output_func=None, test_user=test_runner_username)
@@ -523,6 +533,8 @@ def generate_validate_node_count_func(expected_nodes):
 def test_0110_vcd_cse_cluster_resize(test_runner_username, config):
     """Test 'vcd cse cluster resize ...' commands."""
     node_pattern = r'(node-\S+)'
+    template_name = env.TEMPLATE_DEFINITIONS[0]['name']
+    template_revision = env.TEMPLATE_DEFINITIONS[0]['revision']
     cmd_binder = collections.namedtuple('UserCmdBinder',
                                         'cmd exit_code validate_output_func '
                                         'test_user')
@@ -549,7 +561,8 @@ def test_0110_vcd_cse_cluster_resize(test_runner_username, config):
 
     cmd_list = [
         cmd_binder(cmd=f"cse cluster resize -N {num_nodes+1} -n {env.TEST_NETWORK}"  # noqa
-                       f" {env.USERNAME_TO_CLUSTER_NAME[test_runner_username]}", # noqa: E501
+                       f" {env.USERNAME_TO_CLUSTER_NAME[test_runner_username]}"
+                       f" -t {template_name} -r {template_revision}",
                    exit_code=0, validate_output_func=generate_validate_node_count_func(num_nodes+1), # noqa
                    test_user=test_runner_username),
         cmd_binder(cmd=f"cse cluster resize -N 0 -n {env.TEST_NETWORK}" # noqa
@@ -575,6 +588,8 @@ def test_0120_vcd_cse_node_operation(test_runner_username, config):
     :param test_runner_username: parameterized persona to run tests with
     different users
     """
+    template_name = env.TEMPLATE_DEFINITIONS[0]['name']
+    template_revision = env.TEMPLATE_DEFINITIONS[0]['revision']
     node_pattern = r'(node-\S+)'
     num_nodes = 0 # last resize scaled the cluster down to 0 nodes
     cmd_binder = collections.namedtuple('UserCmdBinder',
@@ -591,7 +606,8 @@ def test_0120_vcd_cse_node_operation(test_runner_username, config):
         cmd_binder(cmd=f"vdc use {env.TEST_VDC}", exit_code=0,
                    validate_output_func=None, test_user=test_runner_username),
         cmd_binder(cmd=f"cse node create {env.USERNAME_TO_CLUSTER_NAME[test_runner_username]}"  # noqa
-                       f" -n {env.TEST_NETWORK}", exit_code=0,
+                       f" -n {env.TEST_NETWORK} -t {template_name}"
+                       f" -r {template_revision}", exit_code=0,
                    validate_output_func=None, test_user=test_runner_username)
     ]
     execute_commands(cmd_list)
